@@ -22,9 +22,9 @@ impl Service for TidesService {
 
 impl ServiceClient {
     #[maybe_async]
-    /// The *Tides* service can be used to retrieve predicted tidal information over a given time
+    /// The *Tides* service can be used to retrieve predicted tidal data over a given time
     /// interval for a specific place.
-    pub async fn get_tidal_information(
+    pub async fn get_tidal_data(
         &self,
         request: &TidesRequest,
     ) -> Result<Result<TidesResponse, ApiError>, Error> {
